@@ -1,7 +1,5 @@
 #include "disk.h"
 
-const char* ffDetectDisksImpl(FFlist* disks);
-
 static int compareDisks(const FFDisk* disk1, const FFDisk* disk2)
 {
     return ffStrbufComp(&disk1->mountpoint, &disk2->mountpoint);
@@ -9,7 +7,7 @@ static int compareDisks(const FFDisk* disk1, const FFDisk* disk2)
 
 const char* ffDetectDisks(FFDiskOptions* options, FFlist* disks)
 {
-    const char* error = ffDetectDisksImpl(disks);
+    const char* error = ffDetectDisksImpl(options, disks);
 
     if (error) return error;
     if (disks->length == 0) return "No disks found";
