@@ -1,14 +1,12 @@
 #pragma once
 
-#ifndef FF_INCLUDED_detection_media
-#define FF_INCLUDED_detection_media
-
 #include "fastfetch.h"
+#include "modules/media/option.h"
 
 typedef struct FFMediaResult
 {
     FFstrbuf error;
-    FFstrbuf busNameShort; //e.g. plasma-browser-integration
+    FFstrbuf playerId; // Bus name on Linux, app bundle name on macOS. e.g. plasma-browser-integration
     FFstrbuf player; // e.g. Google Chrome
     FFstrbuf song;
     FFstrbuf artist;
@@ -17,6 +15,4 @@ typedef struct FFMediaResult
     FFstrbuf status;
 } FFMediaResult;
 
-const FFMediaResult* ffDetectMedia(const FFinstance* instance);
-
-#endif
+const FFMediaResult* ffDetectMedia();
