@@ -4,7 +4,7 @@
 
 #define FF_DISK_MODULE_NAME "Disk"
 
-void ffPrintDisk(FFDiskOptions* options);
+bool ffPrintDisk(FFDiskOptions* options);
 void ffInitDiskOptions(FFDiskOptions* options);
 void ffDestroyDiskOptions(FFDiskOptions* options);
 
