@@ -4,7 +4,7 @@
 
 #define FF_WIFI_MODULE_NAME "Wifi"
 
-void ffPrintWifi(FFWifiOptions* options);
+bool ffPrintWifi(FFWifiOptions* options);
 void ffInitWifiOptions(FFWifiOptions* options);
 void ffDestroyWifiOptions(FFWifiOptions* options);
 
